==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/cpptools/stringtable.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QAtomicInt>
#include <QMutex>
#include <QObject>
#include <QRunnable>
#include <QSet>
#include <QTimer>

namespace CppTools {
namespace Internal {

class StringTable: public QObject
{
    Q_OBJECT

public:
    StringTable();

    QString insert(const QString &string);
    void scheduleGC();

private:
    void startGC();
    void GC();

    class GCRunner: public QRunnable {
        StringTable &m_stringTable;

    public:
        GCRunner(StringTable &stringTable): m_stringTable(stringTable) {}
        virtual void run() { m_stringTable.GC(); }
    } m_gcRunner;
    friend class GCRunner;

private:
    mutable QMutex m_lock;
    QAtomicInt m_stopGCRequested;
    QSet<QString> m_strings;
    QTimer m_gcCountDown;
};

} // Internal namespace
} // CppTools namespace

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/cpptools/stringtable.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QString>

namespace CppTools {
namespace Internal {

class CppToolsPluginPrivate;

class StringTable
{
public:
    static QString insert(const QString &string);
    static void scheduleGC();

private:
    friend class CppToolsPluginPrivate;
    static void initialize();
    static void destroy();
};

} // Internal
} // CppTools
